@@ -11,9 +11,8 @@
 #'
 #' The default category ('groupCol') is 'intended_target_family'. Depending
 #' on the study, other categories may be more relevant. The best resource on these
-#' groupings is the "ToxCast Assay Annotation Data User Guide" directly from
-#' EPA \url{https://www.epa.gov/chemical-research/toxcast-assay-annotation-data-user-guide}.
-#' Following that link, it defines "intended_target_family" as "the target family of the
+#' groupings is the "ToxCast Assay Annotation Data User Guide".
+#' It defines "intended_target_family" as "the target family of the
 #' objective target for the assay". Much more detail can be discovered in that documentation.
 #'
 #' @param ep Data frame containing Endpoint information from ToxCast
@@ -49,7 +48,7 @@ filter_groups <- function(ep,
   assay_source_name <- assay_component_endpoint_name <- ".dplyr"
 
   ep <- ep[, c("assay_component_endpoint_name", groupCol, "assay_source_name")] %>%
-    rename(
+    dplyr::rename(
       endPoint = assay_component_endpoint_name,
       assaysFull = assay_source_name
     )
